#include "csapp.h"
#include "config.h"

/* My program computes a sequence of results that must be checked by
   two functions that I don't trust, check1 and check2. Each of those
   gets half of my secret value and an indication of where it changed
   (0 means "everywhere"), and the checkers must produce the same
   updated result from their respective halves.

   This file shows how I'd call check1 and check2 (imagine that
   they're loaded from separate shared libraries) if I trusted them
   not to troll through memory to find the other half of the secret or
   the other checker's result. But I don't trust them...
 */

void compute_initial_secrets(int *secret1, int *secret2);
void adjust_secrets(int *secret1, int *secret2, int i);
    
void check1(int *secret1, int *answer1, int i);
void check2(int *secret2, int *answer2, int i);

static int *alloc() {
  return malloc(SIZE * sizeof(int));
}

int main()
{
  int *secret1 = alloc();
  int *secret2 = alloc();
  int *answer1 = alloc();
  int *answer2 = alloc();
  int i;

  compute_initial_secrets(secret1, secret2);

  for (i = 0; i < ITERS; i++) {
    adjust_secrets(secret1, secret2, i);
    
    check1(secret1, answer1, i);
    check2(secret2, answer2, i);
    
    if (memcmp(answer1, answer2, SIZE * sizeof(int))) {
      printf("disagree %d\n", i);
      exit(1);
    }
  }

  printf("ok\n");
  return 0;
}
